package com.malk.yiyao.service;

import com.alibaba.fastjson.JSONObject;
import com.malk.server.common.McR;

public interface YiyaoService {
    McR updateYiyao1();

    McR updateYiyao2();

    McR updateYiyao3();

    McR updateYiyao4();

    McR updateYiyao5();

    McR updateYiyao6();

    McR updateYiyao7();

    McR updateYiyao8();

    McR updateYiyao9();

    McR updateYiyao10();

    void getCheckInData(JSONObject eventJson);
}
